@@ -3,7 +3,7 @@ from sparclur.parsers import PDFium
 from parser_tests import ParserTestMixin, RendererTestMixin, TEST_PDF
 
 
-class GhostscriptTestCase(unittest.TestCase, ParserTestMixin, RendererTestMixin):
+class PDFiumTestCase(unittest.TestCase, ParserTestMixin, RendererTestMixin):
 
     def setUp(self):
         self.parser = PDFium
